@@ -22,6 +22,8 @@ use crate::conversion;
 use crate::errors;
 use crate::estimation;
 use crate::estimation::alignment_properties::AlignmentProperties;
+//use crate::estimation::sample_variants;
+//use crate::estimation::tumor_mutational_burden;
 use crate::filtration;
 use crate::grammar;
 use crate::reference;
@@ -293,6 +295,31 @@ pub enum PlotKind {
         #[structopt(long = "sample", required = true, help = "Sample to plot.")]
         sample: String,
     },
+    #[structopt(
+        name = "scatter",
+        about = "Plot variant allelic fraction scatter plot overlayed with a contour plot between two sample groups",
+        usage = "varlociraptor plot scatter --somatic-tumor-events SOMATIC_TUMOR \
+        --sample-y sample1 --sample-x sample2 sample3 < calls.bcf | vg2svg > scatter.svg",
+        setting = structopt::clap::AppSettings::ColoredHelp,
+    )]
+    Scatter {
+        #[structopt(
+            long = "somatic-tumor-events",
+            default_value = "SOMATIC_TUMOR",
+            help = "Events to consider (e.g. SOMATIC_TUMOR)."
+        )]
+        somatic_tumor_events: Vec<String>,
+        #[structopt(
+            long = "sample-x",
+            help = "Name of the first sample in the given VCF/BCF."
+        )]
+        sample_x: String,
+        #[structopt(
+            long = "sample-y",
+            help = "Name(s) of the alternative sample(s) in the given VCF/BCF. Multiple samples can be given."
+        )]
+        sample_y: Vec<String>,
+    },
 }
 
 #[derive(Debug, StructOpt, Serialize, Deserialize, Clone)]
@@ -1032,6 +1059,15 @@ pub fn run(opt: Varlociraptor) -> Result<()> {
 
                 prior.plot(&sample, &sample_infos.names)?;
             }
+            PlotKind::Scatter {
+                somatic_tumor_events,
+                sample_x,
+                sample_y,
+            } => estimation::sample_variants::vaf_scatter(
+                &somatic_tumor_events,
+                &sample_x,
+                &sample_y,
+            )?,
         },
     }
     Ok(())
