@@ -3,25 +3,37 @@
 // This file may not be copied, modified, or distributed
 // except according to those terms.
 
+use std::cell::RefCell;
+use std::cmp;
+use std::rc::Rc;
+use std::sync::Arc;
+
 use anyhow::Result;
+use bio::stats::pairhmm::EmissionParameters;
 use bio::stats::LogProb;
 use bio_types::genome::{self, AbstractInterval, AbstractLocus};
 
 use crate::estimation::alignment_properties::AlignmentProperties;
+use crate::reference;
+use crate::utils;
 use crate::variants::evidence::bases::prob_read_base;
 use crate::variants::evidence::observation::Strand;
+use crate::variants::evidence::realignment::pairhmm::{ReadEmission, RefBaseEmission};
+use crate::variants::evidence::realignment::{Realignable, Realigner};
 use crate::variants::types::{
     AlleleSupport, AlleleSupportBuilder, Overlap, SingleEndEvidence, SingleLocus, Variant,
 };
+use crate::{default_emission, default_ref_base_emission};
 
-pub(crate) struct SNV {
+pub(crate) struct SNV<R: Realigner> {
     locus: SingleLocus,
     ref_base: u8,
     alt_base: u8,
+    realigner: RefCell<R>,
 }
 
-impl SNV {
-    pub(crate) fn new(locus: genome::Locus, ref_base: u8, alt_base: u8) -> Self {
+impl<R: Realigner> SNV<R> {
+    pub(crate) fn new(locus: genome::Locus, ref_base: u8, alt_base: u8, realigner: R) -> Self {
         SNV {
             locus: SingleLocus::new(genome::Interval::new(
                 locus.contig().to_owned(),
@@ -29,11 +41,38 @@ impl SNV {
             )),
             ref_base: ref_base.to_ascii_uppercase(),
             alt_base: alt_base.to_ascii_uppercase(),
+            realigner: RefCell::new(realigner),
         }
     }
 }
 
-impl Variant for SNV {
+impl<'a, R: Realigner> Realignable<'a> for SNV<R> {
+    type EmissionParams = SNVEmissionParams<'a>;
+
+    fn alt_emission_params(
+        &self,
+        read_emission_params: Rc<ReadEmission<'a>>,
+        ref_buffer: Arc<reference::Buffer>,
+        _: &genome::Interval,
+        ref_window: usize,
+    ) -> Result<Vec<SNVEmissionParams<'a>>> {
+        let start = self.locus.range().start as usize;
+
+        let ref_seq = ref_buffer.seq(self.locus.contig())?;
+
+        let ref_seq_len = ref_seq.len();
+        Ok(vec![SNVEmissionParams {
+            ref_seq,
+            ref_offset: start.saturating_sub(ref_window),
+            ref_end: cmp::min(start + 1 + ref_window, ref_seq_len),
+            alt_start: start,
+            alt_base: self.alt_base,
+            read_emission: read_emission_params,
+        }])
+    }
+}
+
+impl<R: Realigner> Variant for SNV<R> {
     type Evidence = SingleEndEvidence;
     type Loci = SingleLocus;
 
@@ -58,54 +97,65 @@ impl Variant for SNV {
         read: &SingleEndEvidence,
         _: &AlignmentProperties,
     ) -> Result<Option<AlleleSupport>> {
-        if let Some(qpos) = read
-            .cigar_cached()
-            .unwrap()
-            // TODO expect u64 in read_pos
-            .read_pos(self.locus.range().start as u32, false, false)?
-        {
-            let read_base = unsafe { read.seq().decoded_base_unchecked(qpos as usize) };
-            let base_qual = unsafe { *read.qual().get_unchecked(qpos as usize) };
-            let prob_alt = prob_read_base(read_base, self.alt_base, base_qual);
-
-            // METHOD: instead of considering the actual REF base, we assume that REF is whatever
-            // base the read has at this position (if not the ALT base). This way, we avoid biased
-            // allele frequencies at sites with multiple alternative alleles.
-            // Note that this is an approximation. The real solution would be to have multiple allele
-            // frequency variables in the likelihood function, but that would be computationally
-            // more demanding (leading to a combinatorial explosion).
-            // However, the approximation is pretty accurate, because it will only matter for true
-            // multiallelic cases. Sequencing errors won't have a severe effect on the allele frequencies
-            // because they are too rare.
-            let non_alt_base = if read_base != self.alt_base {
-                read_base
-            } else {
-                self.ref_base
-            };
-
-            let prob_ref = prob_read_base(read_base, non_alt_base, base_qual);
-            let strand = if prob_ref != prob_alt {
-                Strand::from_record_and_pos(read, qpos as usize)?
-            } else {
-                // METHOD: if record is not informative, we don't want to
-                // retain its information (e.g. strand).
-                Strand::no_strand_info()
-            };
-
-            Ok(Some(
-                AlleleSupportBuilder::default()
-                    .prob_ref_allele(prob_ref)
-                    .prob_alt_allele(prob_alt)
-                    .strand(strand)
-                    .read_position(Some(qpos))
-                    .build()
-                    .unwrap(),
-            ))
+        if utils::contains_indel_op(&**read) {
+            // METHOD: reads containing indel operations should always be realigned,
+            // as their support or non-support of the SNV might be an artifact
+            // of the aligner.
+            Ok(Some(self.realigner.borrow_mut().allele_support(
+                &**read,
+                [&self.locus].iter(),
+                self,
+            )?))
         } else {
-            // a read that spans an SNV might have the respective position deleted (Cigar op 'D')
-            // or reference skipped (Cigar op 'N'), and the library should not choke on those reads
-            // but instead needs to know NOT to add those reads (as observations) further up
-            Ok(None)
+            if let Some(qpos) = read
+                .cigar_cached()
+                .unwrap()
+                // TODO expect u64 in read_pos
+                .read_pos(self.locus.range().start as u32, false, false)?
+            {
+                let read_base = unsafe { read.seq().decoded_base_unchecked(qpos as usize) };
+                let base_qual = unsafe { *read.qual().get_unchecked(qpos as usize) };
+                let prob_alt = prob_read_base(read_base, self.alt_base, base_qual);
+
+                // METHOD: instead of considering the actual REF base, we assume that REF is whatever
+                // base the read has at this position (if not the ALT base). This way, we avoid biased
+                // allele frequencies at sites with multiple alternative alleles.
+                // Note that this is an approximation. The real solution would be to have multiple allele
+                // frequency variables in the likelihood function, but that would be computationally
+                // more demanding (leading to a combinatorial explosion).
+                // However, the approximation is pretty accurate, because it will only matter for true
+                // multiallelic cases. Sequencing errors won't have a severe effect on the allele frequencies
+                // because they are too rare.
+                let non_alt_base = if read_base != self.alt_base {
+                    read_base
+                } else {
+                    self.ref_base
+                };
+
+                let prob_ref = prob_read_base(read_base, non_alt_base, base_qual);
+                let strand = if prob_ref != prob_alt {
+                    Strand::from_record_and_pos(read, qpos as usize)?
+                } else {
+                    // METHOD: if record is not informative, we don't want to
+                    // retain its information (e.g. strand).
+                    Strand::no_strand_info()
+                };
+
+                Ok(Some(
+                    AlleleSupportBuilder::default()
+                        .prob_ref_allele(prob_ref)
+                        .prob_alt_allele(prob_alt)
+                        .strand(strand)
+                        .read_position(Some(qpos))
+                        .build()
+                        .unwrap(),
+                ))
+            } else {
+                // a read that spans an SNV might have the respective position in the
+                // reference skipped (Cigar op 'N'), and the library should not choke on those reads
+                // but instead needs to know NOT to add those reads (as observations) further up
+                Ok(None)
+            }
         }
     }
 
@@ -114,6 +164,40 @@ impl Variant for SNV {
     }
 }
 
+/// Emission parameters for PairHMM over insertion allele.
+pub(crate) struct SNVEmissionParams<'a> {
+    ref_seq: Arc<Vec<u8>>,
+    ref_offset: usize,
+    ref_end: usize,
+    alt_start: usize,
+    alt_base: u8,
+    read_emission: Rc<ReadEmission<'a>>,
+}
+
+impl<'a> RefBaseEmission for SNVEmissionParams<'a> {
+    #[inline]
+    fn ref_base(&self, i: usize) -> u8 {
+        let i_ = i + self.ref_offset;
+
+        if i_ < self.alt_start || i_ >= self.alt_start + 1 {
+            self.ref_seq[i_]
+        } else {
+            self.alt_base
+        }
+    }
+
+    default_ref_base_emission!();
+}
+
+impl<'a> EmissionParameters for SNVEmissionParams<'a> {
+    default_emission!();
+
+    #[inline]
+    fn len_x(&self) -> usize {
+        self.ref_end - self.ref_offset
+    }
+}
+
 // #[cfg(test)]
 // mod tests {
 
